@@ -160,7 +160,7 @@ class FrameworkDetectorFactory:
         for framework_name in cls._detectors:
             detector = cls._detectors[framework_name]("")
             names[framework_name] = detector.display_name
-        names[""] = "Unknown"
+        names["NA"] = "NA"
         
         return names
     
@@ -177,7 +177,7 @@ class FrameworkDetectorFactory:
         types = {}
         for framework_name in cls._detectors:
             types[framework_name] = FrameworkType.from_string(framework_name)
-        types[""] = FrameworkType.UNKNOWN
+        types["NA"] = FrameworkType.NA
         
         return types
     
