@@ -8,7 +8,7 @@ and structured data handling throughout the application.
 from datetime import datetime
 from enum import Enum
 from typing import Dict, Optional
-from pydantic import BaseModel, Field, validator
+from pydantic import BaseModel, Field, field_validator, model_validator
 
 
 class FrameworkType(Enum):
@@ -45,8 +45,8 @@ class FrameworkType(Enum):
     DRUPAL = "drupal"
     DRUSH = "drush"
     
-    # Unknown/No framework detected
-    UNKNOWN = ""
+    # NA/No framework detected
+    NA = "NA"
     
     @property
     def display_name(self) -> str:
@@ -69,9 +69,9 @@ class FrameworkType(Enum):
             FrameworkType.ZENDFRAMEWORK: "Zend Framework",
             FrameworkType.DRUPAL: "Drupal",
             FrameworkType.DRUSH: "Drush",
-            FrameworkType.UNKNOWN: "Unknown"
+            FrameworkType.NA: "NA"
         }
-        return display_names.get(self, "Unknown")
+        return display_names.get(self, "NA")
     
     @property
     def description(self) -> str:
@@ -94,9 +94,9 @@ class FrameworkType(Enum):
             FrameworkType.ZENDFRAMEWORK: "Enterprise PHP framework",
             FrameworkType.DRUPAL: "Content management framework",
             FrameworkType.DRUSH: "Command-line shell and scripting interface for Drupal",
-            FrameworkType.UNKNOWN: "No framework detected or unknown framework"
+            FrameworkType.NA: "No framework detected or NA framework"
         }
-        return descriptions.get(self, "No framework detected or unknown framework")
+        return descriptions.get(self, "No framework detected or NA framework")
     
     @classmethod
     def from_string(cls, value: str) -> "FrameworkType":
@@ -104,12 +104,12 @@ class FrameworkType(Enum):
         try:
             return cls(value.lower().strip())
         except ValueError:
-            return cls.UNKNOWN
+            return cls.NA
     
     @classmethod
     def get_all_frameworks(cls) -> list["FrameworkType"]:
-        """Get all framework types except UNKNOWN."""
-        return [ft for ft in cls if ft != cls.UNKNOWN]
+        """Get all framework types except NA."""
+        return [ft for ft in cls if ft != cls.NA]
     
     @classmethod
     def get_major_frameworks(cls) -> list["FrameworkType"]:
@@ -183,38 +183,74 @@ class FrameworkInfo(BaseModel):
     version: Optional[str] = Field(None, description="Detected framework version")
     confidence: int = Field(100, ge=0, le=100, description="Detection confidence score")
     
-    @validator('confidence')
+    @field_validator('confidence')
+    @classmethod
     def validate_confidence(cls, v: int) -> int:
         """Ensure confidence is within valid range."""
         if not 0 <= v <= 100:
             raise ValueError('Confidence must be between 0 and 100')
         return v
     
-    @validator('name', pre=True, always=True)
-    def set_name_from_framework_type(cls, v: Optional[str], values: Dict) -> str:
+    @field_validator('name', mode="before")
+    @classmethod
+    def set_name_from_framework_type(cls, v: Optional[str], info) -> str:
         """Set name from framework type if not provided."""
         if v is not None:
             return v
-        framework_type = values.get('framework_type')
+        framework_type = info.data.get('framework_type')
         if framework_type:
-            return framework_type.display_name
-        return "Unknown"
+            # Handle both enum and string
+            if isinstance(framework_type, FrameworkType):
+                return framework_type.display_name
+            elif isinstance(framework_type, str):
+                try:
+                    return FrameworkType(framework_type).display_name
+                except Exception:
+                    return str(framework_type)
+        return "NA"
     
-    @validator('description', pre=True, always=True)
-    def set_description_from_framework_type(cls, v: Optional[str], values: Dict) -> str:
+    @field_validator('description', mode="before")
+    @classmethod
+    def set_description_from_framework_type(cls, v: Optional[str], info) -> str:
         """Set description from framework type if not provided."""
         if v is not None:
             return v
-        framework_type = values.get('framework_type')
+        framework_type = info.data.get('framework_type')
         if framework_type:
-            return framework_type.description
-        return "No framework detected or unknown framework"
+            if isinstance(framework_type, FrameworkType):
+                return framework_type.description
+            elif isinstance(framework_type, str):
+                try:
+                    return FrameworkType(framework_type).description
+                except Exception:
+                    return "No framework detected or NA framework"
+        return "No framework detected or NA framework"
     
     @property
     def code(self) -> str:
         """Get framework code for backward compatibility."""
         return self.framework_type.value
 
+    @model_validator(mode="after")
+    def ensure_name_and_description(self):
+        if self.name is None:
+            if isinstance(self.framework_type, FrameworkType):
+                self.name = self.framework_type.display_name
+            elif isinstance(self.framework_type, str):
+                try:
+                    self.name = FrameworkType(self.framework_type).display_name
+                except Exception:
+                    self.name = str(self.framework_type)
+        if self.description is None:
+            if isinstance(self.framework_type, FrameworkType):
+                self.description = self.framework_type.description
+            elif isinstance(self.framework_type, str):
+                try:
+                    self.description = FrameworkType(self.framework_type).description
+                except Exception:
+                    self.description = "No framework detected or NA framework"
+        return self
+
 
 class DetectionResult(BaseModel):
     """
@@ -235,20 +271,27 @@ class DetectionResult(BaseModel):
     detection_time: datetime = Field(default_factory=datetime.now, description="Detection timestamp")
     total_frameworks: Optional[int] = Field(None, description="Total frameworks checked")
     
-    @validator('detected_name', pre=True, always=True)
-    def set_detected_name_from_framework_type(cls, v: Optional[str], values: Dict) -> str:
+    @field_validator('detected_name', mode="before")
+    @classmethod
+    def set_detected_name_from_framework_type(cls, v: Optional[str], info) -> str:
         """Set detected name from framework type if not provided."""
         if v is not None:
             return v
-        detected_framework = values.get('detected_framework')
+        detected_framework = info.data.get('detected_framework')
         if detected_framework:
-            return detected_framework.display_name
-        return "Unknown"
+            if isinstance(detected_framework, FrameworkType):
+                return detected_framework.display_name
+            elif isinstance(detected_framework, str):
+                try:
+                    return FrameworkType(detected_framework).display_name
+                except Exception:
+                    return str(detected_framework)
+        return "NA"
     
     @property
     def is_framework_detected(self) -> bool:
         """Check if a framework was detected."""
-        return self.detected_framework != FrameworkType.UNKNOWN
+        return self.detected_framework != FrameworkType.NA
     
     @property
     def confidence_score(self) -> int:
@@ -256,8 +299,17 @@ class DetectionResult(BaseModel):
         return self.scores.get(self.detected_framework, 0)
     
     @property
-    def top_frameworks(self, limit: int = 5) -> Dict[FrameworkType, int]:
-        """Get top N frameworks by score."""
+    def top_frameworks(self) -> Dict[FrameworkType, int]:
+        """Get top 5 frameworks by score (property)."""
+        sorted_scores = sorted(
+            self.scores.items(),
+            key=lambda x: x[1],
+            reverse=True
+        )
+        return dict(sorted_scores[:5])
+
+    def get_top_frameworks(self, limit: int = 5) -> Dict[FrameworkType, int]:
+        """Get top N frameworks by score (method)."""
         sorted_scores = sorted(
             self.scores.items(),
             key=lambda x: x[1],
@@ -270,6 +322,18 @@ class DetectionResult(BaseModel):
         """Get framework code for backward compatibility."""
         return self.detected_framework.value
 
+    @model_validator(mode="after")
+    def ensure_detected_name(self):
+        if self.detected_name is None:
+            if isinstance(self.detected_framework, FrameworkType):
+                self.detected_name = self.detected_framework.display_name
+            elif isinstance(self.detected_framework, str):
+                try:
+                    self.detected_name = FrameworkType(self.detected_framework).display_name
+                except Exception:
+                    self.detected_name = str(self.detected_framework)
+        return self
+
 
 class DetectionConfig(BaseModel):
     """
@@ -289,8 +353,18 @@ class DetectionConfig(BaseModel):
     max_file_size: int = Field(1024 * 1024, ge=1024, description="Max file size to read")
     timeout: int = Field(30, ge=1, le=300, description="Detection timeout in seconds")
     verbose: bool = Field(False, description="Enable verbose logging")
+
+    @field_validator('timeout', mode="before")
+    @classmethod
+    def cast_timeout_to_int(cls, v):
+        if isinstance(v, float):
+            v = int(v)
+        if v < 1:
+            raise ValueError('Timeout must be at least 1 second')
+        return v
     
-    @validator('max_file_size')
+    @field_validator('max_file_size')
+    @classmethod
     def validate_max_file_size(cls, v: int) -> int:
         """Ensure max file size is reasonable."""
         if v < 1024:
