@@ -238,9 +238,9 @@ class TestDetectionAsync:
                 
                 result = await detect_frameworks_async(temp_project_dir)
                 
-                # Should return "" for unknown framework
-                assert result.detected_framework == FrameworkType.UNKNOWN
-                assert result.detected_name == "Unknown"
+                # Should return "" for NA framework
+                assert result.detected_framework == FrameworkType.NA
+                assert result.detected_name == "NA"
 
 
 class TestDisplayResults:
@@ -289,10 +289,10 @@ class TestDisplayResults:
         except Exception as e:
             pytest.fail(f"display_results raised exception: {e}")
     
-    def test_display_results_unknown_framework(self):
-        """Test displaying results with unknown framework."""
+    def test_display_results_NA(self):
+        """Test displaying results with NA framework."""
         result = DetectionResult(
-            detected_framework=FrameworkType.UNKNOWN,
+            detected_framework=FrameworkType.NA,
             scores={FrameworkType.LARAVEL: 5, FrameworkType.SYMFONY: 10},
             project_path="/test/path"
         )
