@@ -125,8 +125,8 @@ class TestFrameworkMetadata:
         symfony_metadata = FrameworkMetadata(framework_type=FrameworkType.SYMFONY)
         assert symfony_metadata.framework_code == "symfony"
         
-        unknown_metadata = FrameworkMetadata(framework_type=FrameworkType.UNKNOWN)
-        assert unknown_metadata.framework_code == ""
+        NA_metadata = FrameworkMetadata(framework_type=FrameworkType.NA)
+        assert NA_metadata.framework_code == "NA"
 
 
 class TestFrameworkInfo:
@@ -187,11 +187,11 @@ class TestFrameworkInfo:
     
     def test_auto_generated_values(self):
         """Test auto-generated name and description."""
-        # Test with unknown framework
-        info = FrameworkInfo(framework_type=FrameworkType.UNKNOWN)
-        assert info.name == "Unknown"
-        assert info.description == "No framework detected or unknown framework"
-        assert info.code == ""
+        # Test with NA framework
+        info = FrameworkInfo(framework_type=FrameworkType.NA)
+        assert info.name == "NA"
+        assert info.description == "No framework detected or NA framework"
+        assert info.code == "NA"
         
         # Test with known framework
         info = FrameworkInfo(framework_type=FrameworkType.CODEIGNITER)
@@ -208,7 +208,7 @@ class TestDetectionResult:
         scores = {
             FrameworkType.LARAVEL: 95,
             FrameworkType.SYMFONY: 20,
-            FrameworkType.UNKNOWN: 0
+            FrameworkType.NA: 0
         }
         
         result = DetectionResult(
@@ -227,19 +227,19 @@ class TestDetectionResult:
         assert isinstance(result.detection_time, datetime)
         assert result.total_frameworks is None
     
-    def test_detection_result_unknown(self):
-        """Test DetectionResult with unknown framework."""
-        scores = {FrameworkType.UNKNOWN: 0}
+    def test_detection_result_NA(self):
+        """Test DetectionResult with NA framework."""
+        scores = {FrameworkType.NA: 0}
         
         result = DetectionResult(
-            detected_framework=FrameworkType.UNKNOWN,
+            detected_framework=FrameworkType.NA,
             scores=scores,
             project_path="/path/to/project"
         )
         
-        assert result.detected_framework == FrameworkType.UNKNOWN
-        assert result.detected_name == "Unknown"
-        assert result.detected_framework_code == ""
+        assert result.detected_framework == FrameworkType.NA
+        assert result.detected_name == "NA"
+        assert result.detected_framework_code == "NA"
         assert result.is_framework_detected is False
         assert result.confidence_score == 0
     
@@ -288,11 +288,11 @@ class TestDetectionResult:
         )
         
         # Test with limit=2
-        top_frameworks = result.top_frameworks(limit=2)
+        top_frameworks = result.get_top_frameworks(limit=2)
+        # Should return top 2 frameworks
         assert len(top_frameworks) == 2
-        framework_list = list(top_frameworks.keys())
-        assert framework_list[0] == FrameworkType.LARAVEL
-        assert framework_list[1] == FrameworkType.SYMFONY
+        assert list(top_frameworks.keys())[0] == FrameworkType.LARAVEL
+        assert list(top_frameworks.keys())[1] == FrameworkType.SYMFONY
     
     def test_custom_detection_time(self):
         """Test DetectionResult with custom detection time."""
