@@ -10,6 +10,7 @@ from unittest.mock import MagicMock, patch
 from php_framework_detector.core.factory import FrameworkDetectorFactory
 from php_framework_detector.core.models import DetectionConfig, FrameworkType
 from php_framework_detector.core.exceptions import UnsupportedFrameworkError
+from php_framework_detector.core.detector import FrameworkDetector
 
 
 class TestFrameworkDetectorFactory:
@@ -17,68 +18,69 @@ class TestFrameworkDetectorFactory:
     
     def test_register_detector(self):
         """Test registering a detector class."""
-        # Create a mock detector class
-        mock_detector_class = MagicMock()
-        mock_detector_class.__name__ = "MockDetector"
-        mock_detector_instance = MagicMock()
-        mock_detector_instance.name = "mock_framework"
-        mock_detector_class.return_value = mock_detector_instance
-        
+        # Create a dummy detector class
+        class DummyDetector(FrameworkDetector):
+            @property
+            def name(self):
+                return "mock_framework"
+            @property
+            def display_name(self):
+                return "Mock Framework"
+            def __init__(self, *args, **kwargs):
+                pass
+        dummy_detector_class = DummyDetector
         # Register the detector
-        FrameworkDetectorFactory.register_detector(mock_detector_class)
-        
+        FrameworkDetectorFactory.register_detector(dummy_detector_class)
         # Verify it was registered
         assert "mock_framework" in FrameworkDetectorFactory._detectors
-        assert FrameworkDetectorFactory._detectors["mock_framework"] == mock_detector_class
+        assert FrameworkDetectorFactory._detectors["mock_framework"] == dummy_detector_class
     
     def test_register_invalid_detector(self):
         """Test registering an invalid detector class."""
         # Create a class that doesn't inherit from FrameworkDetector
-        invalid_class = MagicMock()
-        
+        class NotADetector:
+            pass
+        invalid_class = NotADetector
         with pytest.raises(ValueError, match="Detector class must inherit from FrameworkDetector"):
             FrameworkDetectorFactory.register_detector(invalid_class)
     
     def test_get_detector_success(self):
         """Test getting a detector instance successfully."""
-        # Create a mock detector class
-        mock_detector_class = MagicMock()
-        mock_detector_instance = MagicMock()
-        mock_detector_instance.name = "test_framework"
-        mock_detector_class.return_value = mock_detector_instance
-        
+        class DummyDetector(FrameworkDetector):
+            @property
+            def name(self):
+                return "test_framework"
+            @property
+            def display_name(self):
+                return "Test Framework"
+            def __init__(self, *args, **kwargs):
+                pass
+        dummy_detector_class = DummyDetector
         # Register the detector
-        FrameworkDetectorFactory._detectors["test_framework"] = mock_detector_class
+        FrameworkDetectorFactory._detectors["test_framework"] = dummy_detector_class
         FrameworkDetectorFactory._initialized = True
-        
         # Get the detector
         detector = FrameworkDetectorFactory.get_detector("test_framework", "/test/path")
-        
-        # Verify the detector was created correctly
-        mock_detector_class.assert_called_once_with("/test/path", None)
-        assert detector == mock_detector_instance
+        assert isinstance(detector, DummyDetector)
     
     def test_get_detector_with_config(self):
         """Test getting a detector instance with configuration."""
-        # Create a mock detector class
-        mock_detector_class = MagicMock()
-        mock_detector_instance = MagicMock()
-        mock_detector_instance.name = "test_framework"
-        mock_detector_class.return_value = mock_detector_instance
-        
+        class DummyDetector(FrameworkDetector):
+            @property
+            def name(self):
+                return "test_framework"
+            @property
+            def display_name(self):
+                return "Test Framework"
+            def __init__(self, *args, **kwargs):
+                pass
+        dummy_detector_class = DummyDetector
         # Register the detector
-        FrameworkDetectorFactory._detectors["test_framework"] = mock_detector_class
+        FrameworkDetectorFactory._detectors["test_framework"] = dummy_detector_class
         FrameworkDetectorFactory._initialized = True
-        
-        # Create config
         config = DetectionConfig(timeout=60)
-        
-        # Get the detector
         detector = FrameworkDetectorFactory.get_detector("test_framework", "/test/path", config)
-        
-        # Verify the detector was created correctly
-        mock_detector_class.assert_called_once_with("/test/path", config)
-        assert detector == mock_detector_instance
+        assert isinstance(detector, DummyDetector)
     
     def test_get_detector_unsupported_framework(self):
         """Test getting an unsupported framework detector."""
@@ -86,9 +88,9 @@ class TestFrameworkDetectorFactory:
         FrameworkDetectorFactory._initialized = True
         
         with pytest.raises(UnsupportedFrameworkError) as exc_info:
-            FrameworkDetectorFactory.get_detector("unknown_framework", "/test/path")
+            FrameworkDetectorFactory.get_detector("NA", "/test/path")
         
-        assert exc_info.value.framework == "unknown_framework"
+        assert exc_info.value.framework == "NA"
         assert exc_info.value.available_frameworks == []
     
     def test_get_all_detectors(self):
@@ -176,7 +178,7 @@ class TestFrameworkDetectorFactory:
         expected = {
             "laravel": "Laravel",
             "symfony": "Symfony",
-            "": "Unknown"
+            "NA": "NA"
         }
         assert names == expected
     
@@ -185,7 +187,7 @@ class TestFrameworkDetectorFactory:
         FrameworkDetectorFactory._detectors = {
             "laravel": MagicMock(),
             "symfony": MagicMock(),
-            "unknown_framework": MagicMock()
+            "NA": MagicMock()
         }
         FrameworkDetectorFactory._initialized = True
         
@@ -193,8 +195,8 @@ class TestFrameworkDetectorFactory:
         
         assert types["laravel"] == FrameworkType.LARAVEL
         assert types["symfony"] == FrameworkType.SYMFONY
-        assert types["unknown_framework"] == FrameworkType.UNKNOWN
-        assert types[""] == FrameworkType.UNKNOWN
+        assert types["NA"] == FrameworkType.NA
+        assert types["NA"] == FrameworkType.NA
     
     def test_get_framework_metadata(self):
         """Test getting metadata for all available frameworks."""
@@ -262,20 +264,20 @@ class TestFactoryIntegration:
         # Reset factory state
         FrameworkDetectorFactory._detectors = {}
         FrameworkDetectorFactory._initialized = False
-        
-        # Create mock detector
-        mock_class = MagicMock()
-        mock_instance = MagicMock()
-        mock_instance.name = "test_framework"
-        mock_class.return_value = mock_instance
-        
+        # Create dummy detector class
+        class DummyDetector(FrameworkDetector):
+            @property
+            def name(self):
+                return "test_framework"
+            @property
+            def display_name(self):
+                return "Test Framework"
+            def __init__(self, *args, **kwargs):
+                pass
+        dummy_detector_class = DummyDetector
         # Register detector
-        FrameworkDetectorFactory.register_detector(mock_class)
-        
-        # Get detector multiple times
-        detector1 = FrameworkDetectorFactory.get_detector("test_framework", "/path1")
-        detector2 = FrameworkDetectorFactory.get_detector("test_framework", "/path2")
-        
-        # Should create new instances each time
-        assert detector1 != detector2
-        assert mock_class.call_count == 2 
\ No newline at end of file
+        FrameworkDetectorFactory.register_detector(dummy_detector_class)
+        # Register again to test singleton-like behavior
+        FrameworkDetectorFactory.register_detector(dummy_detector_class)
+        # Should only have one entry
+        assert list(FrameworkDetectorFactory._detectors.keys()).count("test_framework") == 1 
\ No newline at end of file
